@@ -47,6 +47,7 @@ type ExecuteOptions = {
  * The command line program.
  */
 export class Program {
+  absolutePackageDir: string;
   yargs: any;
   commands: { [key: string]: Function };
   shouldExitProgram: boolean;
@@ -66,13 +67,24 @@ export class Program {
     argv = argv || process.argv.slice(2);
 
     // NOTE: always initialize yargs explicitly with the package dir
-    // so that we are sure that it is going to load the 'boolean-negation: false'
-    // config (See web-ext#469 for rationale).
+    // to avoid side-effects due to yargs looking for its configuration
+    // section from a package.json file stored in an arbitrary directory
+    // (e.g. in tests yargs would end up loading yargs config from the
+    // mocha package.json). web-ext package.json doesn't contain any yargs
+    // section as it is deprecated and we configure yargs using
+    // yargs.parserConfiguration. See web-ext#469 for rationale.
     const yargsInstance = yargs(argv, absolutePackageDir);
 
+    this.absolutePackageDir = absolutePackageDir;
     this.verboseEnabled = false;
     this.shouldExitProgram = true;
     this.yargs = yargsInstance;
+
+    // The following yargs configuration option is needed to fix #304.
+    this.yargs.parserConfiguration({
+      'boolean-negation': false,
+    });
+
     this.yargs.strict();
 
     this.commands = {};
@@ -113,10 +125,10 @@ export class Program {
     this.options = {...this.options, ...options};
     Object.keys(options).forEach((key) => {
       options[key].global = true;
-      if (options[key].demand === undefined) {
+      if (options[key].demandOption === undefined) {
         // By default, all options should be "demanded" otherwise
         // yargs.strict() will think they are missing when declared.
-        options[key].demand = true;
+        options[key].demandOption = true;
       }
     });
     this.yargs.options(options);
@@ -137,7 +149,6 @@ export class Program {
   }
 
   async execute(
-    absolutePackageDir: string,
     {
       checkForUpdates = defaultUpdateChecker,
       systemProcess = process,
@@ -154,9 +165,10 @@ export class Program {
     this.yargs.exitProcess(this.shouldExitProgram);
 
     const argv = this.yargs.argv;
+
     const cmd = argv._[0];
 
-    const version = getVersion(absolutePackageDir);
+    const version = getVersion(this.absolutePackageDir);
     const runCommand = this.commands[cmd];
 
     if (argv.verbose) {
@@ -173,14 +185,15 @@ export class Program {
         throw new UsageError(`Unknown command: ${cmd}`);
       }
       if (globalEnv === 'production') {
-        checkForUpdates ({
-          version: getVersion(absolutePackageDir),
-        });
+        checkForUpdates({version});
       }
 
       const configFiles = [];
 
-      if (argv.configDiscovery) {
+      // Because of an issue with yargs special handling for '--no-' option prefix (See #306)
+      // we need to look explicitly for the options  --config-discovery and --no-config-discovery
+      // (See #1307).
+      if (argv.configDiscovery && !argv.noConfigDiscovery) {
         log.debug(
           'Discovering config files. ' +
           'Set --no-config-discovery to disable');
@@ -283,8 +296,8 @@ export function main(
     runOptions = {},
   }: MainParams = {}
 ): Promise<any> {
-
   const program = new Program(argv, {absolutePackageDir});
+  const version = getVersion(absolutePackageDir);
 
   // yargs uses magic camel case expansion to expose options on the
   // final argv object. For example, the 'artifacts-dir' option is alternatively
@@ -302,7 +315,7 @@ Example: $0 --help run.
     .help('help')
     .alias('h', 'help')
     .env(envPrefix)
-    .version(() => getVersion(absolutePackageDir))
+    .version(version)
     .demandCommand(1, 'You must specify a command')
     .strict();
 
@@ -327,33 +340,35 @@ Example: $0 --help run.
       alias: 'v',
       describe: 'Show verbose output',
       type: 'boolean',
+      demandOption: false,
     },
     'ignore-files': {
       alias: 'i',
       describe: 'A list of glob patterns to define which files should be ' +
                 'ignored. (Example: --ignore-files=path/to/first.js ' +
                 'path/to/second.js "**/*.log")',
-      demand: false,
+      demandOption: false,
       requiresArg: true,
       type: 'array',
     },
     'no-input': {
       describe: 'Disable all features that require standard input',
       type: 'boolean',
+      demandOption: false,
     },
     'config': {
       alias: 'c',
       describe: 'Path to a CommonJS config file to set ' +
         'option defaults',
       default: undefined,
-      demand: false,
+      demandOption: false,
       requiresArg: true,
       type: 'string',
     },
     'config-discovery': {
       describe: 'Discover config files in home directory and ' +
         'working directory. Disable with --no-config-discovery.',
-      demand: false,
+      demandOption: false,
       default: true,
       type: 'boolean',
     },
@@ -380,32 +395,32 @@ Example: $0 --help run.
       commands.sign, {
         'api-key': {
           describe: 'API key (JWT issuer) from addons.mozilla.org',
-          demand: true,
+          demandOption: true,
           type: 'string',
         },
         'api-secret': {
           describe: 'API secret (JWT secret) from addons.mozilla.org',
-          demand: true,
+          demandOption: true,
           type: 'string',
         },
         'api-url-prefix': {
           describe: 'Signing API URL prefix',
           default: 'https://addons.mozilla.org/api/v3',
-          demand: true,
+          demandOption: true,
           type: 'string',
         },
         'api-proxy': {
           describe:
             'Use a proxy to access the signing API. ' +
             'Example: https://yourproxy:6000 ',
-          demand: false,
+          demandOption: false,
           type: 'string',
         },
         'id': {
           describe:
             'A custom ID for the extension. This has no effect if the ' +
             'extension already declares an explicit ID in its manifest.',
-          demand: false,
+          demandOption: false,
           type: 'string',
         },
         'timeout': {
@@ -425,7 +440,7 @@ Example: $0 --help run.
                   'firefox-android). Specify this option multiple times to ' +
                   'run against multiple targets.',
         default: 'firefox-desktop',
-        demand: false,
+        demandOption: false,
         type: 'array',
       },
       'firefox': {
@@ -435,7 +450,7 @@ Example: $0 --help run.
                   'If not specified, the default Firefox will be used. ' +
                   'You can specify the following aliases in lieu of a path: ' +
                   'firefox, beta, nightly, firefoxdeveloperedition.',
-        demand: false,
+        demandOption: false,
         type: 'string',
       },
       'firefox-profile': {
@@ -444,25 +459,25 @@ Example: $0 --help run.
                   'can be specified as a directory or a name, such as one ' +
                   'you would see in the Profile Manager. If not specified, ' +
                   'a new temporary profile will be created.',
-        demand: false,
+        demandOption: false,
         type: 'string',
       },
       'keep-profile-changes': {
         describe: 'Run Firefox directly in custom profile. Any changes to ' +
                   'the profile will be saved.',
-        demand: false,
+        demandOption: false,
         type: 'boolean',
       },
       'no-reload': {
         describe: 'Do not reload the extension when source files change',
-        demand: false,
+        demandOption: false,
         type: 'boolean',
       },
       'pre-install': {
         describe: 'Pre-install the extension into the profile before ' +
                   'startup. This is only needed to support older versions ' +
                   'of Firefox.',
-        demand: false,
+        demandOption: false,
         type: 'boolean',
       },
       'pref': {
@@ -470,7 +485,7 @@ Example: $0 --help run.
                   '(example: --pref=general.useragent.locale=fr-FR). ' +
                   'You can repeat this option to set more than one ' +
                   'preference.',
-        demand: false,
+        demandOption: false,
         requiresArg: true,
         type: 'array',
         coerce: coerceCLICustomPreference,
@@ -478,39 +493,45 @@ Example: $0 --help run.
       'start-url': {
         alias: ['u', 'url'],
         describe: 'Launch firefox at specified page',
-        demand: false,
+        demandOption: false,
         requiresArg: true,
         type: 'array',
       },
       'browser-console': {
         alias: ['bc'],
         describe: 'Open the DevTools Browser Console.',
-        demand: false,
+        demandOption: false,
         type: 'boolean',
       },
+      'args': {
+        alias: ['arg'],
+        describe: 'Additional CLI options passed to the Browser binary',
+        demandOption: false,
+        type: 'array',
+      },
       // Firefox for Android CLI options.
       'adb-bin': {
         describe: 'Specify a custom path to the adb binary',
-        demand: false,
+        demandOption: false,
         type: 'string',
         requiresArg: true,
       },
       'adb-host': {
         describe: 'Connect to adb on the specified host',
-        demand: false,
+        demandOption: false,
         type: 'string',
         requiresArg: true,
       },
       'adb-port': {
         describe: 'Connect to adb on the specified port',
-        demand: false,
+        demandOption: false,
         type: 'string',
         requiresArg: true,
       },
       'adb-device': {
         alias: ['android-device'],
         describe: 'Connect to the specified adb device name',
-        demand: false,
+        demandOption: false,
         type: 'string',
         requiresArg: true,
       },
@@ -519,7 +540,7 @@ Example: $0 --help run.
           'Run a specific Firefox for Android APK. ' +
           'Example: org.mozilla.fennec_aurora'
         ),
-        demand: false,
+        demandOption: false,
         type: 'string',
         requiresArg: true,
       },
@@ -564,5 +585,5 @@ Example: $0 --help run.
     .command('docs', 'Open the web-ext documentation in a browser',
              commands.docs, {});
 
-  return program.execute(absolutePackageDir, runOptions);
+  return program.execute({getVersion, ...runOptions});
 }
